From c89a5c5c8ce190f437e75f8466c75cac5acff3fb Mon Sep 17 00:00:00 2001
From: Stephen Gran <Stephen.Gran@ioko.com>
Date: Thu, 13 Jan 2011 12:38:50 +0000
Subject: [PATCH] Reduce duplication of code

We use the same code in several places instead of calling a function.
Call the function instead.
Signed-off-by: Stephen Gran <Stephen.Gran@ioko.com>
---
 common/objects.c |   66 ++++++++++++++----------------------------------------
 1 files changed, 17 insertions(+), 49 deletions(-)

diff --git a/common/objects.c b/common/objects.c
index cc1ec84..396fa67 100644
--- a/common/objects.c
+++ b/common/objects.c
@@ -2800,23 +2800,29 @@ int is_service_member_of_servicegroup(servicegroup *group, service *svc){
  * The cgi's stopped using it quite long ago though, so we need only
  * compile it if we're building the core
  */
-#ifdef NSCORE
 int is_contact_member_of_contactgroup(contactgroup *group, contact *cntct)
 {
 	contactsmember *member;
+	contact *temp_contact=NULL;
 
 	if (!group || !cntct)
 		return FALSE;
 
 	/* search all contacts in this contact group */
 	for (member = group->members; member; member = member->next) {
-		if (member->contact_ptr == cntct)
+#ifdef NSCORE
+		temp_contact=member->contact_ptr;
+#else
+		temp_contact=find_contact(member->contact_name);
+#endif
+		if(temp_contact==NULL)
+			continue;
+		if (temp_contact == cntct)
 			return TRUE;
 	}
 
 	return FALSE;
 }
-#endif /* NSCORE */
 
 /*  tests whether a contact is a contact for a particular host */
 int is_contact_for_host(host *hst, contact *cntct){
@@ -2851,18 +2857,8 @@ int is_contact_for_host(host *hst, contact *cntct){
 #endif
 		if(temp_contactgroup==NULL)
 			continue;
-
-		for(temp_contactsmember=temp_contactgroup->members;temp_contactsmember!=NULL;temp_contactsmember=temp_contactsmember->next){
-#ifdef NSCORE
-			temp_contact=temp_contactsmember->contact_ptr;
-#else
-			temp_contact=find_contact(temp_contactsmember->contact_name);
-#endif
-			if(temp_contact==NULL)
-				continue;
-			if(temp_contact==cntct)
-				return TRUE;
-			}
+		if(is_contact_member_of_contactgroup(temp_contactgroup,cntct))
+			return TRUE;
 		}
 
 	return FALSE;
@@ -2905,18 +2901,9 @@ int is_escalated_contact_for_host(host *hst, contact *cntct){
 #endif
 			if(temp_contactgroup==NULL)
 				continue;
+			if(is_contact_member_of_contactgroup(temp_contactgroup,cntct))
+				return TRUE;
 
-			for(temp_contactsmember=temp_contactgroup->members;temp_contactsmember!=NULL;temp_contactsmember=temp_contactsmember->next){
-#ifdef NSCORE
-				temp_contact=temp_contactsmember->contact_ptr;
-#else
-				temp_contact=find_contact(temp_contactsmember->contact_name);
-#endif
-				if(temp_contact==NULL)
-					continue;
-				if(temp_contact==cntct)
-					return TRUE;
-				}
 			}
 		}
 
@@ -2955,18 +2942,9 @@ int is_contact_for_service(service *svc, contact *cntct){
 #endif
 		if(temp_contactgroup==NULL)
 			continue;
+		if(is_contact_member_of_contactgroup(temp_contactgroup,cntct))
+			return TRUE;
 
-		for(temp_contactsmember=temp_contactgroup->members;temp_contactsmember!=NULL;temp_contactsmember=temp_contactsmember->next){
-#ifdef NSCORE
-			temp_contact=temp_contactsmember->contact_ptr;
-#else
-			temp_contact=find_contact(temp_contactsmember->contact_name);
-#endif
-			if(temp_contact==NULL)
-				continue;
-			if(temp_contact==cntct)
-				return TRUE;
-			}
 		}
 
 	return FALSE;
@@ -3008,18 +2986,8 @@ int is_escalated_contact_for_service(service *svc, contact *cntct){
 #endif
 			if(temp_contactgroup==NULL)
 				continue;
-
-			for(temp_contactsmember=temp_contactgroup->members;temp_contactsmember!=NULL;temp_contactsmember=temp_contactsmember->next){
-#ifdef NSCORE
-				temp_contact=temp_contactsmember->contact_ptr;
-#else
-				temp_contact=find_contact(temp_contactsmember->contact_name);
-#endif
-				if(temp_contact==NULL)
-					continue;
-				if(temp_contact==cntct)
-					return TRUE;
-				}
+			if(is_contact_member_of_contactgroup(temp_contactgroup,cntct))
+				return TRUE;
 			}
 	        }
 
-- 
1.7.2.3

